### A Pluto.jl notebook ###
# v0.20.4

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    #! format: off
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
    #! format: on
end

# ╔═╡ de358d50-fa53-405c-85ad-b1f0b0ce3fbd
begin
	using HypertextLiteral, PlutoUI, PlutoPlotly, LinearAlgebra, NLsolve, PlotlyKaleido
	using Dates, PeriodicalDates, DataFrames, CSV, Statistics, PlutoTeachingTools 
	PlotlyKaleido.start()
    force_pluto_mathjax_local(true)
    PlotlyKaleido.start(;mathjax = true)
end

# ╔═╡ 51e9ba0a-7793-4cf4-a0c1-bc90aecff9c6
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
"""

# ╔═╡ 0125c893-46aa-457c-bd1b-18589e9ab2d3
md"""
# Day 1 - Welcome to Pluto Notebooks

## Introduction to Pluto
"""

# ╔═╡ 41a74197-ceb9-40b6-8d24-1712f8d93b1a
md"""
**Vivaldo Mendes**

**03 February 2025**
"""

# ╔═╡ 2606832a-1d82-417a-93a8-623fe40149f6
md"""
---
"""

# ╔═╡ 182cbbb9-2783-4a46-865e-036df9ee1320
md"""
### Packages used in this notebook
"""

# ╔═╡ 69c09e47-6c6e-441c-90e2-a3863d9ca71f
md"""
---
"""

# ╔═╡ 0d1f1f47-ecd8-4d16-80b4-d9154bc7cc9a
md"""
## 1. What is a Pluto notebook?
"""

# ╔═╡ ffadd7f9-ce62-4218-aa4d-cbc4a78b00fb
md"""
A notebook is a document with two types of cells (see image below): 
- code cells
- markdown cells 

The first type of cells includes computational code, short comments, and Pluto's "begin-end" blocks. Code cells produce an output, which usually takes the form of a plot, a table, numbers, or symbols.

The second type of cell (markdown) allows for the writing of standard text, mathematics, and inserting an image or a video, among other functionalities. 

The versatility that arises from combining markdown cells with code cells makes notebooks a remarkable tool for computational work in general and teaching in particular. The following image provides an overview of most elements composing a notebook. They will be explained in more detail in the next section.
"""

# ╔═╡ dcfb9cc7-6816-4948-a9f9-0481974110da
Resource("https://vivaldomendes.org/images/depot/Pluto_cells.png", :width=>850)

# ╔═╡ 33c4fce7-c7d5-43e4-b9cf-0fac9f2b7fea
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ fb354c4b-3641-4051-ac10-bd8f9559af62
md"""
## 2. Pluto basic tips
"""

# ╔═╡ 7d7e0cb3-a9c7-4740-a771-a78904a0e5fb
md"""
#### Opening a new cell
"""

# ╔═╡ 8c11bc9b-e709-45e0-9b3e-56020bfb1a57
md"""

- Put the mouse on top of any opened/visible cell. 
- You will see a $+$ sign in the top and bottom left corners (**_see image below_**).
- Click on the $+$ sign where you want the new cell to be placed.
"""

# ╔═╡ a469b8ac-49ab-49a6-b7d3-dcb11ca30cad
Resource("https://modernmacro.org/resources/vivaldo/figures/Pluto_basic_tips_Edited.png", :width=>900)

# ╔═╡ b8c49887-dca0-483a-bd7a-f910cdbeb3b5
md"""
#### How to run a cell?

- Click on the small circle-arrow on the bottom right hand-side of each cell (▶)
- Or, just click simultaneosly on `shift` and `enter`
"""

# ╔═╡ 071cb217-8ad9-4fe6-ba61-66d5e38fdc95
md"""
### How to run a cell?

- See **_image above_**
- Click on the small circle-arrow in the bottom right-hand-side of each cell (▶)
- Or, click simultaneosly on **Shift** and **Enter**

"""

# ╔═╡ 609f216a-d5f9-41ee-866c-dc3c1d3fbd77
md"""
### How to save a notebook?

- When a cell is run, this action will be automatically saved
- If we forget to run a particular cell, click simultaneously on **Ctrl** and **s** to save all changes that may have been implemented and not yet saved.

"""

# ╔═╡ d37a4740-e637-47d7-b398-d48776d95a86
md"""
### Code cells
"""

# ╔═╡ 7e6c36aa-8ae1-46fc-a5dc-3c270a0ac14c
md"""

- When we click on the $+$ sign, as shown above, a new cell will be automatically opened
- By default, this new cell will be a code cell
- The next cell is an empty code cell that can be used for computation. For example, type 2+2 and run it.

"""

# ╔═╡ b152b2df-a68b-48cf-b2ce-3b892b8bf09e
md"""
### Markdown cells
"""

# ╔═╡ 1564e2db-474b-4a87-803f-fe7da9261885
md"""
- If we want to write text or mathematics in a new cell, or insert a video, we have to turn it into a "markdown" cell
- To change a cell from code mode into **_markdown mode_**, put the cursor inside the cell you want to be in markdown.
  - Click on the following: **Ctrl** and **m** simultaneously. 
- That is all. You can start typing text or mathematics as you like.

"""

# ╔═╡ d8c7f3dc-3343-4f68-b523-b2f037785634
md"""
!!! tip
	To write text in bold, italics, or mathematical symbols do the following: 
	- type: `**This is bold**` to get: **This is bold**
	- type: `_This is italics_` to get: _This is italics_
	- type: `**_This is bold and italics_**` to get: **_This is bold and italics_**
	- type: `$y=2x^2$` to get a mathematical expression: $y=2x^2$
"""

# ╔═╡ 18727fde-29ed-419e-ad50-0faf1a711484
md"""
#### Bold and Italics
"""

# ╔═╡ f494ad06-2b19-47be-96be-fb6b24cb3aa0
md"""
This is **bold**

This is _italics_

This is **_bold and italics_**

"""

# ╔═╡ 0f9c0bf9-c4c9-492f-8343-551a9cbadfb2
md"""
#### Lists
"""

# ╔═╡ abe31398-0b94-4783-ad8e-fa909fa3d1d3
md"""
- This is my first item

- This is my second item

  - Two tabs give my first sub-item

  - My second

    - Four tabs give first sub-sub-item

    - Very easy

- My final item

1. My first numbered item

2. Whau, this is easy

"""

# ╔═╡ ff171bda-a588-4627-85bd-f0f8f913df93
md"""
#### Writting with mathematical symbols
"""

# ╔═╡ 92aedf0f-c666-4372-85fe-29f28dc6fec2
md"""

To write mathematical expressions in markdown, we only need to use the `$`. Start an expression with a `$` and end it with another `$`.

This is inline mathematics: $y=2x$.

This is displayed mathematics:

$$y=2x$$

This is mathematics using the power syntax: $y = 2x^3$

This is mathematics using the fraction syntax: $h = \dfrac{3}{4n}$

This is more elaborate mathematics: $z = \int_{a}^{b} x^2 dx$

This is ... lack of imagination, using greek symbols:

$$\lambda = \sum_{i=0}^{\infty} \alpha^i x_{i-1}$$
"""

# ╔═╡ 654a151d-9d09-4119-a68d-2e40c533be5a
md"""
#### Tables
"""

# ╔═╡ db0df44a-1f61-4ab8-b45a-fcc4a8c0e17f
md"""

| variable           | mean        | min       | median   | max      | 
|:--------------     |:-------:    |:--------: |:--------:|:--------:|           
| Students passed    | 14.9389     | 3.0       | 15.0     | 20       | 
| Midterm test       | 14.6172     | 8.85      | 14.8     | 19.7     | 
| Endterm test       | 15.8715     | 8.1       | 16.3     | 19.85    | 
"""

# ╔═╡ 74010167-4771-4565-99e4-dce565e35e4b
md"""
!!! note "Exercise 1"
 
	- Open a new cell and turn it into markdown mode. Write in this cell the following text: `Today is a sunny day!`
	- Open another cell, turn it into markdown mode, and write the same text but in bold, and also in italics.
	- Open a new cell, turn it into markdown mode, and write the following: This is text and mathematics with a funny equation $y = xz/2$
	- Open a new cell, turn it into markdown mode, and write the following equation: $y = 3x^2$
	
"""

# ╔═╡ 4b438845-97c8-4268-9a58-f97f96f6b93f
md"""
!!! tip "Answer"

	Provide your answer below.	 	 

"""

# ╔═╡ b1f287fe-f2fd-418d-9892-d674105de650
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ aa99585f-4b88-4466-9df6-d0c3d195bbf0
md"""
## 3. Arithmetic operators
"""

# ╔═╡ a1fd4ba1-7c28-4b00-97a3-1ca2913227b0
md"""

	+x	    unary plus	        the identity operation

	-x	    unary minus	      	maps values to their additive inverses

	x + y	binary plus	    	performs addition

	x - y	binary minus		performs subtraction

	x * y	times	        	performs multiplication

	x / y	divide	        	performs division

	x ÷ y	integer divide		x / y, truncated to an integer

	x \ y	inverse divide		equivalent to y / x

	x ^ y	power				raises x to the yth power

	x % y	remainder			equivalent to rem(x,y)'

"""

# ╔═╡ f0b33579-4f78-4537-a70e-073524e22f15
2+3

# ╔═╡ 8ef0f167-66cb-46a6-88d5-7be6bfec46e2
10^4

# ╔═╡ fd300920-4528-413e-807f-c671601b3750
pepe = 10

# ╔═╡ 5808dcf2-8efa-4bc1-93b9-e350f38f38fc
rock = 20

# ╔═╡ 1bdc3f5b-31fc-4abc-a75a-b7c6d0be0165
mary = pepe * rock

# ╔═╡ 6a3abbcf-b0bd-4e7e-a814-8977b112d27c
md"""
`fiona = `$(@bind fiona Slider(-5.0:0.5:5.0, default=1.0, show_value=true))
"""

# ╔═╡ 82294923-9968-4a49-a94f-8ee55fea4664
paty = (fiona * mary , fiona^2 , fiona*mary , 10*fiona)

# ╔═╡ d9d34510-c614-4feb-82a3-ea5e65a6744f
md"""
!!! note "Exercise 2"
 
	What is the value of a variable called "zazu", given the following equation?

	$$zazu = 10 + rock^2 + \frac{pepe}{2}$$
"""

# ╔═╡ e447e90b-cf3e-40c8-8a2b-19dadf7191be


# ╔═╡ a132c1c3-c5d9-461f-b4ac-fd356f16c928
md"""
!!! tip "Answer"

	zazu = ??? 	 	 

"""

# ╔═╡ 37c4d79d-0fbd-49e8-9166-af5f557acabf
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 487fe09a-2079-407d-8cee-6e2db4fe4898
md"""
## 4. Ploting functions
"""

# ╔═╡ c602906d-1116-497e-a708-2031e04014e2
begin
	x =  0.0 : 0.01 : 20.0
	#Ana = 2 * x.^0.5
	Ana = 2 * sin.(x)
end;

# ╔═╡ 6cbcbbe1-e50c-4590-8261-dc03e4240a8f
begin
	fig1 = plot(x, Ana)
	relayout!(fig1, Layout(height = 450, hovermode="x", title_text="My fancy plot", title_x = 0.5, titlefont_size="17"))
	fig1
end

# ╔═╡ 4824f2fe-7c60-43d8-9211-87bfa7aa4065
noise = randn(500)

# ╔═╡ b0373101-a51a-4b52-8ba5-662530a744c9
begin
	fig3 = plot(histogram(x=noise, opacity=0.75,  nbinsx=50), Layout(bargap= 0.05))
end

# ╔═╡ da2bd2d5-c1a5-460b-8240-b3135aa123b1
md"""
!!! note "Exercise 3"
 
	In the following cell, produce a simple plot of the following function: $$e^{Ana}$$ 
	
	by using the following code:`Plot(x, exp.(Ana))`
"""

# ╔═╡ 50de0c4e-6308-488e-b520-805dc9231349
plot(x, exp.(Ana))

# ╔═╡ 4970e6ab-5b01-418f-b22f-b9641ac4d53f
md"""
!!! note "Exercise 3A"
 
	In the next cell, we hide the code that plots three functions together. To run the cell, click on the little eye to bring the cell back to the surface, delete the `;` found in the last line, and finally run the cell (`Shift` and `Enter`, or click on the `run cell` button). The plot will then be produced.
"""

# ╔═╡ a5b1d8ec-23c8-4597-84c0-0b7c93cb5d30
begin
	x2 = LinRange(0, 3*π, 100)
	
	trace1 = scatter(x = x2, y = cos.(x2), line_width = 2, line_color = "blue", name = "Shrek")
	
	trace2 = scatter(x = x2, y = sin.(x2), line_dash = "dashdot", line_color="BlueViolet", name="Fiona")
	
	trace3 = scatter(x = x2, y = cos.(x2).^2 .- 1/2, mode = "markers+lines", marker_symbol = "circle-open",
	 	 			marker_size = "6", marker_color = "red", name = "Donkey", line_width = 0.5)
	
	layout1 = Layout(#font_size = 13, 
				height = 450,
				hovermode="x",	
			   	title_text="My fancy plot with different lines & marker styles", title_x =0.5,
			   	titlefont_size="17")
	
	fig4 = plot([trace1, trace2, trace3],layout1)
end

# ╔═╡ ff8cd19e-8cae-47b3-8c8e-2f127779e570
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 9249b41d-3e4a-4116-b9be-65636e68cac7
md"""
## 5. Magic things we can do with Pluto
"""

# ╔═╡ 8dbe4a85-3bb0-442f-8618-720c0a00af67
md"""
### Write normal text and sophisticated mathematics
"""

# ╔═╡ e6983682-02a8-4d86-b76e-c85235931ebe
md"""
Consider now an optimization problem where the constraints are defined in terms of inequalities. This can be solved by using the famous Karush-Kuhn–Tucker conditions, which require too much space to be explained here. Ax encellent place to look at is Chapter 6 of the textbook: Rangarajan K. Sundaram  (1996). _A First Course in Optimization Theory_, Cambridge University Press.

Using two packages of Julia (JuMP and GLPK), the syntax to solve this problem can be found below. In particular, look how close the Julia syntax is to the mathematical syntax.
"""

# ╔═╡ 0de12035-fc43-445e-a6f8-f97d7234de99
md"""
$$\max \quad x_{1}+2 x_{2}+5 x_{3}
$$

subject to

$$
\begin{aligned}
-x_{1}+x_{2}+3 x_{3} & \leq-5 \\
x_{1}+3 x_{2}-7 x_{3} & \leq 10 \\
0 \leq x_{1} & \leq 10 \\
x_{2} & \geq 0 \\
x_{3} & \geq 0
\end{aligned}$$

And then, blaa blaa blaa ....
"""

# ╔═╡ fee19510-7829-4a1a-b95e-b67b0cdd6798
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ ae7d434b-4623-497e-9fe4-c3b9f3f10e69
md"""
### Use fancy symbols for writing text and doing computation
"""

# ╔═╡ 7212caf4-6d99-4c01-92f4-c3f11be7d446
md"""
I have a 😺 that loves the 🌚, but not 🍍. And I can do write simple text or do computations with these adorable objects. 
"""

# ╔═╡ 95b13f99-c77f-41a2-ab26-8c405296fd17
md"""
!!! tip
	To write special characters (like beta, for example) do the following: 
	- type: `\beta` followed by `Tab`
	- The firt time you do it, you have to click more than one time on the `Tab` key. After that, clicking only once will be enough.
"""

# ╔═╡ cb8fbf86-4646-4888-993d-7f602af2183f
β = 3

# ╔═╡ 0b13ae26-c9ea-440d-b23c-af32664c4730
α = 10 * β

# ╔═╡ cfb5f1f7-9e82-4b64-bede-4c93dc166c20
β^2

# ╔═╡ 0cb64be3-d306-4b2d-8ebf-020aaeb36a11
🍎=5

# ╔═╡ ef67c2d4-50e5-4a75-9d1d-7f20d05ff38f
2*🍎

# ╔═╡ d456b292-6c76-4484-bf76-f74490beb720
😃 = 500

# ╔═╡ e8b65fdc-7a03-4cb8-9865-2e168989b2a8
🍎*🍎 / (2*😃)

# ╔═╡ 37f16fc1-5450-4087-a4f4-72a03db847d4
md"""
!!! note "Exercise 4"
 
	- Open a new cell and turn it into markdown mode. 
	- Write in this cell the following symbols (beta, psi, theta): β ψ θ
"""

# ╔═╡ 41d9598c-3011-4e14-8684-289a172cec10


# ╔═╡ bd1b97c5-04ee-499b-81d7-4bf11e1a4d07
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ c23a2871-6108-4c15-853a-9f2deb41ad53
md"""
### Play with sliders
"""

# ╔═╡ c7c5947b-4caf-4278-af25-c6efdf37557a
md"""
!!! note "Exercise 5"
 
	Move the two sliders above (one slide at a time), and see what happens to the equilibrium in the plot above.
"""

# ╔═╡ 4ba352ad-7f94-4f00-ae90-49c92226d0ae
md"""
	!!! tip "Answer"

		The equilibrium will ....  	 	 

	"""

# ╔═╡ 9c6874cf-6dee-489f-b9ed-89e86ecdb865
md"""
!!! note "Exercise 6"
 
	Move the two sliders above (one slide at a time), and see what happens to the sinusoidal wave below.
"""

# ╔═╡ e1bcc8dd-009f-4f82-832f-0d8db11b700d
md"""
#### Calculate an integral
"""

# ╔═╡ 2557c704-295a-4770-bbeb-41a94257738b
md"""
!!! note "Exercise 7"
 
	We can estimate the integral of a function $F:[a,b] \rightarrow \mathbb{R}$ using the midpoint rule approximation. Let us interactively estimate the $\int_0^1 F(x) d x$ to see the effect of changing the number of subintervals, in the case of:

	$$F(x)= - xsin(2\pi x)$$
"""

# ╔═╡ 4000f0d1-f014-4ed2-bb6e-de637e47a76d
begin
	Nbins_slider = @bind Nbins html"<input type=range min=1 max=500 step=1 value=20>"
		
	md"""Number of intervals: $Nbins_slider"""
end

# ╔═╡ 35c1d390-6b67-4ae4-815b-fd5eebdb1ee2
let
	F(x)=-x*sin(2π*x) 
	centres=1/(2*Nbins):1/Nbins:1
	midpointarea=round(sum(F.(centres))/Nbins, digits=6)
	
	trace01 = bar(x=centres, y=F.(centres), kind="bar", name = "Area")
	trace02 = scatter(x=centres, y= .- centres .* sin.(2 .* π .* centres), name = "F(x)")
		
	plot([trace01, trace02], Layout(height = 450, title_text="midpoint rule estimate with $Nbins intervals = $midpointarea"))
end

# ╔═╡ 04c46c48-a297-4955-90bd-a51b6ad9b310
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ a69868ac-f4e5-4125-9584-7a0750180161
md"""
### Playing with questions & answers 
"""

# ╔═╡ c16f9c18-e776-45c8-bcff-66c78627928d
md"""
!!! note "Exercise 8"
 
	Table 1 shows some important macroeconomic aggregates, measured in **real terms**, for the US economy in 2013. The data in this table has been inserted into the notebook (see cell below). Answer the questions 👉 **a)** and 👉 **b)**
"""

# ╔═╡ 1895d767-4018-43a8-94cd-174f321daca1
md"""
$$\begin{aligned}
& \text {Table 1. Expenditure in the USA in 2013}\\
&\begin{array}{cllr}
\hline \hline \text {  } & \text{Code} & \text {Headings} & \text {Billions of dollars} \\
\hline  
1 & cons & \text{Private Consumption Expenditures} & 11400 &  \\
2 & inve & \text{Investment in Equipment and Structures} & 2600 &  \\
3 & stoc & \text{Inventories} & 80 &  \\
4 & gove & \text{Public Expenditures} & 3120 &  \\
5 & expo & \text{Exports} & 2250 &  \\
6 & impo & \text{Imports} & 3000 &  \\

\hline
\end{array}
\end{aligned}$$

"""

# ╔═╡ 05ce80f3-67e6-4e61-9447-4d703e1c67eb
# values passed into the notebook
cons = 11400 ; inve = 2600 ; stoc = 80 ; gove = 3120 ; expo = 2250 ; impo = 3000 ;

# ╔═╡ edb2c820-0b38-4f4c-8779-b0f45815b086
md"""
👉 **a)** Using Table 1, calculate GDP by the expenditure method. 
"""

# ╔═╡ ad797a54-db6f-4d85-aed2-f8f8ec774c0e
md"""
!!! hint

	According to the usual definition of GDP by the expenditure method, GDP is equal to the sum of  private consumption, plus public expenditure on goods and services, plus investment and inventories, plus exports minus imports.
"""

# ╔═╡ 12692d0c-2a1f-4ef2-b529-451faa7c9b00
GDP = cons + inve + stoc + gove + expo - impo

# ╔═╡ 057e1b24-e9fa-4aa5-b9b1-97181b096851
md"""
	!!! tip "Answer (a) "

		GDP = ??? 

	"""

# ╔═╡ 2c93ad8b-c489-4d37-a39f-a116715f1cfc
md"""
👉 **b)** In a market economy, such as the one we live in, do you have any suggestion about the main macroeconomic variables that explain the behavior of private investment?
"""

# ╔═╡ 5c83f904-5ff8-4056-b6a7-dc4ea8b3c993
md"""
!!! tip "Answer (b) "

	We have not yet discussed the main determinants of private investment in our economies. As we will see later in this course, those determinants are: real interest rates, financial frictions, and autonomous investment decisions.

"""

# ╔═╡ c644bcd3-afef-4446-ae11-2cce4b37eb88
md"""
!!! note "Exercise 8A"
 
	We can use Pluto to create multiple-choice questions with some pedagogic feedback. Try to answer the following question using the bullets below.

"""

# ╔═╡ cb273532-f78e-48f6-9a32-5bbfc05164dc
md"""
How much did the US GDP change in 2023, given the following facts:

- First Republic Bank shareholders lost 2 billion dollars on March 16 due to the bank's collapse.

- Microsoft decided to invest 10 billion dollars in the development of ChatGPT (OpenAI). 

- Amazon bought 100% of the capital of the company One Medical on February 22, 2023 for 4 billion dollars.


**a)** -- 2 billion + 10 billion + 4 billion.

**b)** + 4 billion.

**c)** + 10 billion + 4 billion.

**d)** + 10 billion.

**e)** None of the above.
"""

# ╔═╡ 7f592271-13b2-4d4e-abe7-495172544e14
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ fe2181e1-ef9f-4b6a-aff2-a06f41f166df
md"""
!!! note "Exercise 8B: demand vs supply in a market economy"
 
	As you have studied in introductory microeconomics, price adjustments are the mechanism that equilibrates markets. The following figure illustrates the interaction between supply and demand in a market economy that leads to such adjustments.

	What kind of information can we get by looking at points 1 and 1'? And what happens in the case of points 2 and 2'?

"""

# ╔═╡ 35edcb27-2cde-4fc8-a2ba-7f455493c627
begin
	Q = 0.0 : 0.05 : 25.0
	Pˢ = 0.0 .+ 0.75 .* Q
	Pᵈ = 18.0 .- 0.75 .* Q

	trace9a = scatter(; x = Q, y = Pᵈ,  mode="lines" , line_color = "maroon", line_width = "2.2",	name  = "Qᵈ")
	
	trace9b = scatter(; x = Q, y = Pˢ, mode="lines" , line_color = "Blue", line_width = "2.2",	name  = "Qˢ")


	trace4_2 = scatter(; x =[11.0 , 13.0],  y = [8.25 , 8.25], text =["1", "1'"], textposition = "top center", 
                    name ="", mode="markers+text", marker_size= "11", marker_color="purple", showlegend = false, 		 					hoverinfo="skip", textfont = attr(family="sans serif", size=16, color="black"))

	trace4_3 = scatter(; x =[11.0 , 13.0],  y = [9.75 , 9.75], text =["2", "2'"], textposition = "top center", 
                    name ="", mode="markers+text", marker_size= "11", marker_color="darkorange", showlegend = false, 		 					hoverinfo="skip", textfont = attr(family="sans serif", size=16, color="black"))
	
		
	layout9 = Layout(;
					height = 450,
					title_text ="Demand (Qᵈ) versus supply (Qˢ)",
					title_x = 0.5,
					hovermode = "y",
                    xaxis=attr(title="Quantity", showgrid=true, zeroline=false),
                    xaxis_range = [9.0, 15.0],	
                    yaxis=attr(title="Price", zeroline = false),
					yaxis_range=[6.5 , 11.5]
	)

   fig9 = plot([trace9a, trace9b, trace4_2 , trace4_3], layout9)	
end

# ╔═╡ 2b922c32-d0da-4813-b1ad-abb5167f4ce4
md"""
!!! tip "Answer 8B"

	Points 1 and 1' tell us that for the price level of 8.25, there is  .... .

	Points 2 and 2' tell us that for the price level of 9.75, there is a .... .

	The price will be stable when there is .... .

"""

# ╔═╡ 1fa4dabd-3459-4187-b9f2-7e1eee56d28a
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 8391202d-cec8-4b0c-bfc2-1a01419851d4
md"""
## 6. Downloading and plotting data
"""

# ╔═╡ a1cffba2-aab6-4ce5-b5c1-fe7f55f397f9
md"""
###### Students are not expected to know *_how to do_* the plots below, but they must know *_how to use them_* if asked.
"""

# ╔═╡ f669ec62-dca0-42c9-a7b7-8024f6e9c7a9
md"""
To download the data file attached to this notebook -- its name is _`ECB Data Inflation.csv`_ -- we should do as exemplified below. A CSV file is the most used format to deal with data and it means "comma separated values". This data file contains the inflation rate for the EuroZone as a whole and four individual countries. This data was obtained from [here](https://ec.europa.eu/eurostat/databrowser/view/prc_hicp_manr/default/table?lang=en).

```julia
name_my_data = CSV.read("ECB Data Inflation.csv", DataFrame) 	
```
"""

# ╔═╡ 390010ce-72dd-4b69-a486-7bcc1744859f
inflation = CSV.read("ECB Data Inflation.csv", DataFrame)

# ╔═╡ 43a443c2-3f6d-426f-ab72-bbd67873b92e
md"""
To summarize the data we downloaded, we should do:

```julia
describe(name_my_data)
```
"""

# ╔═╡ 49f95b2d-6186-470b-956c-1e6bb3ae3de2
describe(inflation)

# ╔═╡ abf832f5-7cb4-40e7-a27e-2bdec69c910a
md"""
To plot a single column of `inflation` we can do:
"""

# ╔═╡ cd6c0607-ad69-455d-bc3b-6ce05fc87746
begin
	fig5 = plot(inflation.Months, inflation.Portugal, Layout(height = 450))
end

# ╔═╡ 78e2f78e-061e-4a92-8cce-4c82a46c6e31
md"""
To plot more than one column, we can create a vector `[...]` with as many columns has we wish. In the case below we plot the columns associated with Germany and Portugal.
"""

# ╔═╡ 1a780e63-d0aa-4ad5-a76f-0314c50e3c29
begin
	fig6 = plot(inflation.Months, [inflation.Germany  inflation.Portugal], Layout(height = 450))
end

# ╔═╡ be81679d-e8b1-4dc4-b7d1-489fe363f37f
md"""
We can add a title, the names of the variables (columns), a label to both axis, and a hover functionality into our previous plot. It will look like this (the code is hidden: to show the code click on the little eye button on the left):
"""

# ╔═╡ 49a6d562-d47c-470b-ae54-601fffd12c68
begin
	restyle!(fig6, 1:2, name = ["Germany", "Portugal"]) # names Germany and Portugal on variables 1 and 2
	
	relayout!(fig6, Layout(
		title_text = "Inflation in Germany and Portugal", title_x = 0.5, 
		hovermode = "x", yaxis_title = "Percentage points", 
		xaxis_title = "Monthly observations")) # introduces a title, y-axis label, and the hover-mode
	
	fig6 # Updates the plot
end

# ╔═╡ be1e91a5-011d-425a-be16-ab7b45b6823f
md"""
!!! note "Exercise 9"
 
	We can also save one plot as a "png" file or an "svg" file (among many other formats). These files can be inserted later into another document (like a PowerPoint or a Word file). Their graphical quality will be much higher than by using the archaic "screen-capture" functionality. In the next cell, save "fig6" as a svg file by copying and running the code `savefig(fig6, "inflation.svg")`. It will be automatically saved in the same folder where this notebook is.

"""

# ╔═╡ 9362414b-e883-4569-9f31-f4ce08d9a0e5


# ╔═╡ 9c4a07a8-4144-4e01-ae25-d35c60db5951
begin
	trace1_1 = scatter(;x = inflation.Months, y = inflation.EuroArea, 
				name = "EuroArea", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3, 
            	marker_color = "Blue")
	
	trace1_2 = scatter(;x = inflation.Months, y = inflation.Portugal, 
				name = "Portugal", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3,
            	marker_color = "Red")

	trace1_3 = scatter(;x = inflation.Months, y = inflation.Germany, 
				name = "Germany", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3,
            	marker_color = "Gray")

	trace1_4 = scatter(;x = inflation.Months, y = inflation.Spain, 
				name = "Spain", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3,
            	marker_color = "Purple")

	trace1_5 = scatter(;x = inflation.Months, y = inflation.France, 
				name = "France", mode="markers+lines",
				marker_symbol="circle", marker_size="4",line_width= 0.3,
            	marker_color = "Orange")

	layout1_2 = Layout(;#font_size = 16,
			height = 450,
					
			title_text = "Inflation in the EuroZone and Portugal", title_x=0.5,
		
			hovermode="x",		
		
            xaxis = attr(
               title = "Monthly obervations",
               tickformat = "%Y",
               hoverformat = "%Y-M%m",
               tick0 = "1997/01/01",
               dtick = "M60" ),
		
        	xaxis_range = [Date.(1997), Date.(2024)],
        	yaxis_title = "Percentage points",
        	#yaxis_range=[-2, 2], 
        	titlefont_size = 16)

	fig7 = Plot([trace1_1, trace1_2, trace1_3, trace1_4, trace1_5], layout1_2)
end

# ╔═╡ f84e13af-a1c3-40a5-80a6-b838410b24c7
md"""
!!! note "Exercise 9A"
 
	Create a simple plot of the following variable `inflation.EuroArea .- 2` (EuroArea inflation minus 2% inflation). To achieve that, apply the following code `Plot(inflation.Months, inflation.EuroArea .- 2, kind="bar")` , where `kind="bar"` means that we want the data to be plotted as a bar, not as a line. The level of inflation the European Central Bank wants to see in the Euro Zone is 2%. Check whether the wishes of the ECB have been accomplished in the EU.

"""

# ╔═╡ 11a363b2-90c7-43ac-a563-257056c66908
plot(inflation.Months, inflation.EuroArea .- 2 , kind = "bar", Layout(height = 450))

# ╔═╡ f1fd0927-4d06-41df-8de4-6def18e26a22
md"""
!!! tip "Answer"

	Here

"""

# ╔═╡ da1d8381-5b15-475e-a693-4696689fa6d3
md"""
## 7. Using linear algebra 
"""

# ╔═╡ fdb13094-ef0e-4626-9e57-4110c0d2ccae
md"""
!!! warning

	In computation, there is a crucial difference between a `,` and a `.`. Therefore, do not forget that $1/2=0.5$, NOT $1/2=0,5$. If you mistakenly use a `,` to express decimal units, you will create a problem your computer does not know how to solve.

"""

# ╔═╡ bcc72069-c9c9-4eb9-96a1-8528cd60c100
A = [1 2 3 ; 4 1 6 ; 7 8 1]

# ╔═╡ fa1e19f1-9cbd-4454-9bf1-a1fc8cdcf52a
inv(A) # the inverse of A

# ╔═╡ 5efc650a-92a5-4350-9eda-3e7b61f491f5
transpose(A) # the transpose of A

# ╔═╡ ad3bb2f0-b8b7-489d-8603-53ebd01ab86f
det(A) # the determinant of Bia

# ╔═╡ 2bb008a1-82e2-487f-b2f5-0d27eea804de
A'

# ╔═╡ 789cab47-ef60-4c0c-b380-42d9fadee744
A^2

# ╔═╡ b2bc41af-aba3-484f-97ed-5558987f4d93
Zak = randn(3, 3)

# ╔═╡ 531d6c8a-c325-4e9c-9496-6c69b0abed6b
aple = A * Zak

# ╔═╡ c8bdc59a-b830-41d7-903e-338a17220d18
F=rand(1:10, 5,5)

# ╔═╡ 3a6ae0de-3774-43d1-aad0-0c1e3edd99e8
F[1,3]

# ╔═╡ 0a09e61c-7c2b-4088-9fb8-465189ba1768
md"""
!!! note "Exercise 10"
 
	Let us create a matrix of dimension (100x100), with all its elements as randomly generated numbers. Give this matrix a funny name Shrek: `Shrek = randn(10,10)`

	Calculate the inverse of Shrek. How long does it take your computer to calculate such an inverse matrix?
"""

# ╔═╡ c9b02af3-34ca-4f74-8611-0112b83942bb
Shrek = randn(10,10)

# ╔═╡ 2588a536-5bfd-4af8-8b40-1a918792cd6a
inv(Shrek)

# ╔═╡ b0a9c155-65f7-44f3-a9bf-77447da741ab
md"""
!!! tip "Answer"

	Here

"""

# ╔═╡ 34feb3a2-01a2-48a3-87c7-47000b18c39c
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 93ba50b7-098e-4b3d-a3d4-ad27a5d67e0f
md"""
## 8. Solving a complicated model
"""

# ╔═╡ 5766096f-96dc-44f9-ae72-4f75f441594f
md"""
!!! note "Exercise 11"
 
	Consider the following prototype of a macroeconomic model:

	$\begin{aligned}
	& y_{1} = a + 0.5 y_{2} - 2.5 y_{3} \\
	& y_{2} = -2 y_{1} + 5 y_{3} + b \\
	& y_{3} = 10 y_{1} + 2 c \\
	& a = 10 \ , \ b=2 \ , \ c=5
	\end{aligned}$

	Let us solve this model using the package `NLsolve`. The first thing we should do is to pass the values of the variables with known values to the notebook: $a=10,b=2,c=5$: 

"""

# ╔═╡ 4e40b2ae-3e70-47bc-808f-1acd2615615a
a = 10 ; b = 2 ; c = 5 ; # the data is passed into the notebook

# ╔═╡ 6d7063b7-278f-4d5c-be3e-c4c0edceaf44
md"""
The first thing we have to is to write our model as an homegeneous system (zeros on its left hand side)

$$\begin{aligned}
&0=a+0.5 y_2-2.5 y_3 -y_1 \\
&0=-2 y_1+5 y_3+b -y_2 \\
&0=10 y_1+2 c - y_3
\end{aligned}$$
"""

# ╔═╡ 0e810c29-3155-4d30-9b81-55e6cdc1be5a
md"""
Then, we have to have to write down our problem according to the syntax of NLsolve: 

					Name, Variables, Functions, Solution

- **Name**. Give a name for our problem. Let us name it as _shrek _ problem_

- **Variables**. Define the variables in our problem: v[1], v[2], v[3] 

- **Functions**. Define the functions in our problem: F[1], F[2], F[3] 

- **Solution**. Compute the solution according to the syntax of NLsolve 

  - Give a name to the solution to our problem: let us name it as _shrek _ solution_

  - Call the NLsolve function that will solve the problem (always this one): _nlsolve_ 

  - Choose the problem to be solved (in this case, is _shrek _ problem_), 

  - Give three initial guesses for the package to start the computation. 

    - For linear problems $[0.0 \ ; 0.0 \ ; 0.0]$ always works. 

  - The number of initial guesses must equal the number of unknowns in the model.

In the image below, we provide a detailed step-by-step explanation of how the solution to the problem above is implemented.
"""

# ╔═╡ bdd4566f-3800-4c9c-b91e-ac3c5a65580a
HTML("""
<div style="display: flex; justify-content: center; align-items: center;">
    <img 
		src="http://modernmacro.org/resources/Vivaldo/figures/NLsolve_explained.png" 
	alt="Centered Image" style="max-width: 90%; height: auto;">
</div>
""")

# ╔═╡ 4a4cf9f2-21b5-4685-9ce8-99f76556811c
begin
	#defining the problem
	function shrek_problem(F, v)

		# defining variables
		y1 = v[1] 
        y2 = v[2] 
		y3 = v[3] 

		# deining functions
        F[1] = a + 0.5y2 - 2.5y3 - y1
        F[2] = -2y1 + 5y3 + b - y2
		F[3] = 10y1 + 2c - y3 		
	end

	# computing the solution
	shrek_solution = nlsolve(shrek_problem, [0.0 ; 0.0 ; 0.0])		# computes the solution to the problem 
	shrek_solution.zero  											# rounds off the solution
end

# ╔═╡ 09689df6-67a3-4f6e-aeb3-7bacc4d738e3
md"""
!!! tip "Answer"

	The solution is: y1 = ??, y2 = ??, y3 =??.

"""

# ╔═╡ f51d1b16-ec2c-41d7-97af-56688bef276d
md"""
!!! note "Exercise 11"
 
	Solve the previous exercise by using Linear Algebra. Confirm that the results are the same as one would expect.
"""

# ╔═╡ 9a1f8687-df62-4af4-a33e-c7b864c6f556


# ╔═╡ fd8e8644-aedb-4e1c-a55f-12abba02b1c9


# ╔═╡ 696f0722-80be-453a-8dee-1ceac68f0f0e
md"""
!!! tip "Answer"

	Here

"""

# ╔═╡ 79b30313-e600-4356-b589-69fbb9bdc04d
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 7d10fdd7-197f-45f8-b316-c4774b0a1f79
md"""
## Auxiliary cells (please do not change them)
"""

# ╔═╡ c306ae6c-8acc-440d-94f2-4d17c01fa999
TableOfContents()

# ╔═╡ 9c386789-44b7-4d38-95ca-beeaecb311b0
begin	
	# Demand	
	Ā3 = 8.0
	λ3 = 0.5
	m3 = 2.0
	ϕ3 = 0.2
	r̄3 = 2.0	
	# Supply	
	γ3  = 2.8
	Yᴾ3 = 14.8
	πᵉ3 = 2.0
	ρ3  = 0.0	
	# Intercepts (useful to simplify notation)	
	πd_max3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3        # The AD curve y-axis' intercept
	πs_min3 = πᵉ3 - γ3 * Yᴾ3 + ρ3             # The AS curve y-axis' intercept
end;

# ╔═╡ 13054251-e17d-4469-8a65-281ffd3b5999
begin
	π_ZL3= -r̄3 / (1+λ3)
	πd_min3 = - Ā3 / ϕ3
	Y_ZL3 = Ā3 * m3 - (m3 *  ϕ3 * r̄3) / (1+λ3)
	ρ4 = -3.15
end;

# ╔═╡ df7041ea-07b6-4e13-b463-b6fa7b95111c
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Please, select the correct answer.*
		
		---
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Corret!"

			---
			"""
		else	
			md"""
			!!! danger "👎 Wrong answer"
				
				Try again. **But it is better to study first!!!** 😡

			---
			"""
		end
	end
end;

# ╔═╡ 8419b89c-80c1-427e-bf68-03c3a07e8ef2
tchanã(q20,"d)")

# ╔═╡ cac4054f-21df-4aac-be8e-ac11e30a1181
md"### CSS code"

# ╔═╡ 47831542-8188-496d-b712-b8fc4db18694
begin
      struct TwoColumns{L, R}
    left::L
    right::R
      end
      
      function Base.show(io, mime::MIME"text/html", tc::TwoColumns)
          write(io, """<div style="display: flex;"><div style="flex: 20%;margin-left:19%;">""")
          show(io, mime, tc.left)
          write(io, """</div><div style="flex: 20%;">""")
          show(io, mime, tc.right)
          write(io, """</div></div>""")
      end
end

# ╔═╡ c1d9b788-0454-4fb4-9eca-f08a8f693af5
TwoColumns(
	
md"""

`ΔĀ = `$(@bind ΔĀ Slider(-1.0:0.01:1.0, default=0.0, show_value=true))

""",
	
md"""

`ΔYᴾ = `$(@bind ΔYᴾ Slider(-1.0:0.05:1.0, default=0.0, show_value=true))

"""
)

# ╔═╡ afbb7662-85e1-4a35-b82f-bce445cf0936
begin
	Y3 = 13.8:0.01:15.6
	
	πd3 = πd_max3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3) # AD function
	πs3 = πs_min3 .+ γ3 .*Y3             # AS function
	
	trace9_0 = scatter(; x = [14.8 .+ ΔYᴾ , 14.8 .+ ΔYᴾ] , y = [-5,10] , 
			mode = "line", line_width = "4", name = "Yp", line_color = "Orange")
	
	trace9_1 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y3, y = πs3, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [14.8], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))


	πd_max3_ΔĀ = ((Ā3 .+ ΔĀ) ./ (λ3 .* ϕ3)) .- r̄3 ./ λ3 # New max value of the AD function
	
	πd3_ΔĀ = πd_max3_ΔĀ .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3) # AD function
	
	
	trace9_4 = scatter(; x = Y3, y = πd3_ΔĀ, mode="lines" , line_color = "Magenta", 
					 line_width = "3", name  = "AD2")
		
	#trace9_5 = scatter(; x = [14.21], y = [2.947], text =["2"], 
	#				textposition = "top center", name ="Eq2", mode="markers+text", 
	#				marker_size= "12", marker_color="Magenta",
	#				textfont = attr(family="sans serif", size=16, color="black"))
	
	
	layout9_5 = Layout(;
					height = 450,
					title_text ="Initial long-term equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [14.2, 15.4],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.8 , 5])

   fig0 = plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3], layout9_5)
	
	
end

# ╔═╡ cca6bd64-0735-4bd4-8149-7f03f7f26e57
TwoColumns(
	
md"""

`frequency: `$(@bind frequency Slider(0.0:0.1:3.0, default=1.0, show_value=true))

""",
	
md"""

`damping:  `$(@bind damping Slider(-0.5:0.01:0.8, default=0.0, show_value=true))

"""
)

# ╔═╡ cffd033c-9ba9-4147-922e-2265b9e46485
begin
	τ=1:0.01:20
	plot(τ, (exp.(.-damping * τ) .* sin.(frequency .* τ)), Layout(height = 450))
end

# ╔═╡ d65ae8f6-07be-48f7-a1c8-fc493c5cde43
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1550px;
    		padding-left: max(200px, 10%);
    		padding-right: max(383px, 10%); 
            # 383px to accomodate TableOfContents(aside=true)
		}
	}
	form {
		text-align: center;
		width: fit-content;
		padding: 10px;
  		border: 5px solid #ebebeb;
  		margin: 1em 0 2.5em 0;
		border-radius: 25px;
  		background: #ebebeb;
		color:#1f1f1f;
	}
	form > div {
		display: inline-block;
		margin-left: 0.75em;
		margin-right: 0.75em;
		font-weight: bold;
	}
</style>
"""


# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
Statistics = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"

[compat]
CSV = "~0.10.12"
DataFrames = "~1.7.0"
HypertextLiteral = "~0.9.5"
NLsolve = "~4.5.1"
PeriodicalDates = "~2.0.0"
PlotlyKaleido = "~2.2.5"
PlutoPlotly = "~0.4.4"
PlutoTeachingTools = "~0.2.14"
PlutoUI = "~0.7.55"
Statistics = "~1.11.1"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.11.3"
manifest_format = "2.0"
project_hash = "10d0d7b41844139e4d5dfac3b5c5f62c9441ef3b"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "50c3c56a52972d78e8be9fd135bfb91c9574c140"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "4.1.1"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.2"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra"]
git-tree-sha1 = "017fcb757f8e921fb44ee063a7aafe5f89b86dd1"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.18.0"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceCUDSSExt = "CUDSS"
    ArrayInterfaceChainRulesCoreExt = "ChainRulesCore"
    ArrayInterfaceChainRulesExt = "ChainRules"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceReverseDiffExt = "ReverseDiff"
    ArrayInterfaceSparseArraysExt = "SparseArrays"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    CUDSS = "45b445bb-4962-46a0-9369-b4df9d0f772e"
    ChainRules = "082447d4-558c-5d27-93f4-14fc19e9eca2"
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    ReverseDiff = "37e2e3b7-166d-5795-8a7a-e32c996b4267"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"
version = "1.11.0"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"
version = "1.11.0"

[[deps.BaseDirs]]
git-tree-sha1 = "cb25e4b105cc927052c2314f8291854ea59bf70a"
uuid = "18cc8868-cbac-4acf-b575-c8ff214dc66f"
version = "1.2.4"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "deddd8725e5e1cc49ee205a1964256043720a6c3"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.15"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "7eee164f122511d3e4e1ebadb7956939ea7e1c77"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.6"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "bce6804e5e6044c6daab27bb533d1295e4a2e759"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.6"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "26ec26c98ae1453c692efded2b17e15125a5bea1"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.28.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "362a287c3aa50601b0bc359053d5c2468f0e7ce0"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.11"

[[deps.CommonSubexpressions]]
deps = ["MacroTools"]
git-tree-sha1 = "cda2cfaebb4be89c9084adaca7dd7333369715c5"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.1"

[[deps.Compat]]
deps = ["TOML", "UUIDs"]
git-tree-sha1 = "8ae8d32e09f0dcf42a36b90d4e17f5dd2e4c4215"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.16.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.1.1+0"

[[deps.ConstructionBase]]
git-tree-sha1 = "76219f1ed5771adbb096743bff43fb5fdd4c1157"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.8"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseLinearAlgebraExt = "LinearAlgebra"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "abe83f3a2f1b857aac70ef8b269080af17764bbe"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.16.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "DataStructures", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrecompileTools", "PrettyTables", "Printf", "Random", "Reexport", "SentinelArrays", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "fb61b4812c49343d7ef0b533ba982c46021938a6"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.7.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "1d0a14036acb104d9e89698bd408f63ab58cdc82"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.20"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"
version = "1.11.0"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "c7e3a542b999843086e2f29dac96a618c105be1d"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.12"

    [deps.Distances.extensions]
    DistancesChainRulesCoreExt = "ChainRulesCore"
    DistancesSparseArraysExt = "SparseArrays"

    [deps.Distances.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"
version = "1.11.0"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates"]
git-tree-sha1 = "7878ff7172a8e6beedd1dea14bd27c3c6340d361"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.22"
weakdeps = ["Mmap", "Test"]

    [deps.FilePathsBase.extensions]
    FilePathsBaseMmapExt = "Mmap"
    FilePathsBaseTestExt = "Test"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"
version = "1.11.0"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Setfield"]
git-tree-sha1 = "f089ab1f834470c525562030c8cfde4025d5e915"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.27.0"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffSparseArraysExt = "SparseArrays"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "05882d6995ae5c12bb5f36dd2ed3f61c98cbb172"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.5"

[[deps.Format]]
git-tree-sha1 = "9c68794ef81b08086aeb32eeaf33531668d5f5fc"
uuid = "1fa38f19-a742-5d3f-a2b9-30dd87b9d5f8"
version = "1.3.7"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "a2df1b776752e3f344e5116c06d75a10436ab853"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.38"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"
version = "1.11.0"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "b6d6bfdd7ce25b0f9b2f6b3dd56b2673a66c8770"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.5"

[[deps.InlineStrings]]
git-tree-sha1 = "45521d31238e87ee9f9732561bfee12d4eebd52d"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.2"

    [deps.InlineStrings.extensions]
    ArrowTypesExt = "ArrowTypes"
    ParsersExt = "Parsers"

    [deps.InlineStrings.weakdeps]
    ArrowTypes = "31f734f8-188a-4ce0-8406-c8a06bd891cd"
    Parsers = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"
version = "1.11.0"

[[deps.InvertedIndices]]
git-tree-sha1 = "6da3c4316095de0f5ee2ebd875df8721e7e0bdbe"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.1"

[[deps.IrrationalConstants]]
git-tree-sha1 = "e2222959fbc6c19554dc15174c81bf7bf3aa691c"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.4"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "a007feb38b422fbdab534406aeca1b86823cb4d6"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.7.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "a729439c18f7112cbbd9fcdc1771ecc7f071df6a"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.39"

[[deps.Kaleido_jll]]
deps = ["Artifacts", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "43032da5832754f58d14a91ffbe86d5f176acda9"
uuid = "f7e6163d-2fa5-5f23-b69c-1db539e41963"
version = "0.2.1+0"

[[deps.LaTeXStrings]]
git-tree-sha1 = "dda21b8cbd6a6c40d9d02a73230f9d70fed6918c"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.4.0"

[[deps.Latexify]]
deps = ["Format", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Requires"]
git-tree-sha1 = "ce5f5621cac23a86011836badfedf664a612cee4"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.5"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SparseArraysExt = "SparseArrays"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.6.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
version = "1.11.0"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.7.2+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"
version = "1.11.0"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "e4c3be53733db1051cc15ecf573b1042b3a712a1"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.3.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
version = "1.11.0"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "13ca9e2586b89836fd20cccf56e57e2b9ae7f38f"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.29"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"
version = "1.11.0"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "688d6d9e098109051ae33d126fcfc88c4ce4a021"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "3.1.0"

[[deps.MIMEs]]
git-tree-sha1 = "1833212fd6f580c20d4291da9c1b4e8a655b128e"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "1.0.0"

[[deps.MacroTools]]
git-tree-sha1 = "72aebe0b5051e5143a079a4685a46da330a40472"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.15"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"
version = "1.11.0"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.6+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "ec4f7fbeab05d7747bdf98eb74d130a2a2ed298d"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.2.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"
version = "1.11.0"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.12.12"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "cc0a5deefdb12ab3a096f00a6d42133af4560d71"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.1.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.27+1"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+2"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl"]
git-tree-sha1 = "1346c9208249809840c91b26703912dff463d335"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.6+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "cc4054e898b852042d7b503313f7ad03de99c3dd"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.8.0"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "Random", "SHA", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.11.0"
weakdeps = ["REPL"]

    [deps.Pkg.extensions]
    REPLExt = "REPL"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlotlyKaleido]]
deps = ["Artifacts", "Base64", "JSON", "Kaleido_jll"]
git-tree-sha1 = "ba551e47d7eac212864fdfea3bd07f30202b4a5b"
uuid = "f2990250-8cf9-495f-b13a-cce12b45703c"
version = "2.2.6"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "BaseDirs", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "Reexport", "TOML"]
git-tree-sha1 = "1ae939782a5ce9a004484eab5416411c7190d3ce"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.4.6"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "5d9ab1a4faf25a62bb9d07ef0003396ac258ef1c"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.15"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "7e71a55b87222942f0f9337be62e26b1f103d3e4"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.61"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "36d8b4b899628fb92c2749eb488d884a926614d3"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.3"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "PrecompileTools", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "1101cd475833706e4d0e7b122218257178f48f34"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.4.0"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"
version = "1.11.0"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "StyledStrings", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"
version = "1.11.0"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
version = "1.11.0"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "9bb80533cb9769933954ea4ffbecb3025a783198"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.7.2"
weakdeps = ["Distributed"]

    [deps.Revise.extensions]
    DistributedExt = "Distributed"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "712fb0231ee6f9120e005ccd56297abbc053e7e0"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.8"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"
version = "1.11.0"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"
version = "1.11.0"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "66e0a8e672a0bdfca2c3f5937efb8538b9ddc085"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.2.1"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "64cca0c26b4f31ba18f13f6c12af7c85f478cfde"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.5.0"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "192954ef1208c7019899fbf8049e717f92959682"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.3"

[[deps.Statistics]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "ae3bb1eb3bba077cd276bc5cfc337cc65c3075c0"
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.11.1"

    [deps.Statistics.extensions]
    SparseArraysExt = ["SparseArrays"]

    [deps.Statistics.weakdeps]
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1ff449ad350c9c4cbc756624d6f8a8c3ef56d3ed"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.7.0"

[[deps.StringManipulation]]
deps = ["PrecompileTools"]
git-tree-sha1 = "a6b1675a536c5ad1a60e5a5153e1fee12eb146e3"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.4.0"

[[deps.StyledStrings]]
uuid = "f489334b-da3d-4c2e-b8f0-e476e12c162b"
version = "1.11.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "OrderedCollections", "TableTraits"]
git-tree-sha1 = "598cd7c1f68d1e205689b1c2fe65a9f85846f297"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.12.0"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
version = "1.11.0"

[[deps.TranscodingStreams]]
git-tree-sha1 = "0c45878dcfdcfa8480052b6ab162cdd138781742"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.11.3"

[[deps.Tricks]]
git-tree-sha1 = "6cae795a5a9313bbb4f60683f7263318fc7d1505"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.10"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"
version = "1.11.0"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"
version = "1.11.0"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.11.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.59.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─51e9ba0a-7793-4cf4-a0c1-bc90aecff9c6
# ╟─0125c893-46aa-457c-bd1b-18589e9ab2d3
# ╟─41a74197-ceb9-40b6-8d24-1712f8d93b1a
# ╟─2606832a-1d82-417a-93a8-623fe40149f6
# ╟─182cbbb9-2783-4a46-865e-036df9ee1320
# ╠═de358d50-fa53-405c-85ad-b1f0b0ce3fbd
# ╟─69c09e47-6c6e-441c-90e2-a3863d9ca71f
# ╟─0d1f1f47-ecd8-4d16-80b4-d9154bc7cc9a
# ╟─ffadd7f9-ce62-4218-aa4d-cbc4a78b00fb
# ╟─dcfb9cc7-6816-4948-a9f9-0481974110da
# ╟─33c4fce7-c7d5-43e4-b9cf-0fac9f2b7fea
# ╟─fb354c4b-3641-4051-ac10-bd8f9559af62
# ╟─7d7e0cb3-a9c7-4740-a771-a78904a0e5fb
# ╟─8c11bc9b-e709-45e0-9b3e-56020bfb1a57
# ╠═a469b8ac-49ab-49a6-b7d3-dcb11ca30cad
# ╟─b8c49887-dca0-483a-bd7a-f910cdbeb3b5
# ╟─071cb217-8ad9-4fe6-ba61-66d5e38fdc95
# ╟─609f216a-d5f9-41ee-866c-dc3c1d3fbd77
# ╟─d37a4740-e637-47d7-b398-d48776d95a86
# ╟─7e6c36aa-8ae1-46fc-a5dc-3c270a0ac14c
# ╟─b152b2df-a68b-48cf-b2ce-3b892b8bf09e
# ╟─1564e2db-474b-4a87-803f-fe7da9261885
# ╟─d8c7f3dc-3343-4f68-b523-b2f037785634
# ╟─18727fde-29ed-419e-ad50-0faf1a711484
# ╟─f494ad06-2b19-47be-96be-fb6b24cb3aa0
# ╟─0f9c0bf9-c4c9-492f-8343-551a9cbadfb2
# ╟─abe31398-0b94-4783-ad8e-fa909fa3d1d3
# ╟─ff171bda-a588-4627-85bd-f0f8f913df93
# ╟─92aedf0f-c666-4372-85fe-29f28dc6fec2
# ╟─654a151d-9d09-4119-a68d-2e40c533be5a
# ╟─db0df44a-1f61-4ab8-b45a-fcc4a8c0e17f
# ╟─74010167-4771-4565-99e4-dce565e35e4b
# ╟─4b438845-97c8-4268-9a58-f97f96f6b93f
# ╟─b1f287fe-f2fd-418d-9892-d674105de650
# ╟─aa99585f-4b88-4466-9df6-d0c3d195bbf0
# ╟─a1fd4ba1-7c28-4b00-97a3-1ca2913227b0
# ╠═f0b33579-4f78-4537-a70e-073524e22f15
# ╠═8ef0f167-66cb-46a6-88d5-7be6bfec46e2
# ╠═fd300920-4528-413e-807f-c671601b3750
# ╠═5808dcf2-8efa-4bc1-93b9-e350f38f38fc
# ╠═1bdc3f5b-31fc-4abc-a75a-b7c6d0be0165
# ╟─6a3abbcf-b0bd-4e7e-a814-8977b112d27c
# ╠═82294923-9968-4a49-a94f-8ee55fea4664
# ╟─d9d34510-c614-4feb-82a3-ea5e65a6744f
# ╠═e447e90b-cf3e-40c8-8a2b-19dadf7191be
# ╟─a132c1c3-c5d9-461f-b4ac-fd356f16c928
# ╟─37c4d79d-0fbd-49e8-9166-af5f557acabf
# ╟─487fe09a-2079-407d-8cee-6e2db4fe4898
# ╠═c602906d-1116-497e-a708-2031e04014e2
# ╠═6cbcbbe1-e50c-4590-8261-dc03e4240a8f
# ╠═4824f2fe-7c60-43d8-9211-87bfa7aa4065
# ╠═b0373101-a51a-4b52-8ba5-662530a744c9
# ╟─da2bd2d5-c1a5-460b-8240-b3135aa123b1
# ╟─50de0c4e-6308-488e-b520-805dc9231349
# ╟─4970e6ab-5b01-418f-b22f-b9641ac4d53f
# ╟─a5b1d8ec-23c8-4597-84c0-0b7c93cb5d30
# ╟─ff8cd19e-8cae-47b3-8c8e-2f127779e570
# ╟─9249b41d-3e4a-4116-b9be-65636e68cac7
# ╟─8dbe4a85-3bb0-442f-8618-720c0a00af67
# ╟─e6983682-02a8-4d86-b76e-c85235931ebe
# ╟─0de12035-fc43-445e-a6f8-f97d7234de99
# ╟─fee19510-7829-4a1a-b95e-b67b0cdd6798
# ╟─ae7d434b-4623-497e-9fe4-c3b9f3f10e69
# ╟─7212caf4-6d99-4c01-92f4-c3f11be7d446
# ╟─95b13f99-c77f-41a2-ab26-8c405296fd17
# ╠═cb8fbf86-4646-4888-993d-7f602af2183f
# ╠═0b13ae26-c9ea-440d-b23c-af32664c4730
# ╠═cfb5f1f7-9e82-4b64-bede-4c93dc166c20
# ╠═0cb64be3-d306-4b2d-8ebf-020aaeb36a11
# ╠═ef67c2d4-50e5-4a75-9d1d-7f20d05ff38f
# ╠═d456b292-6c76-4484-bf76-f74490beb720
# ╠═e8b65fdc-7a03-4cb8-9865-2e168989b2a8
# ╟─37f16fc1-5450-4087-a4f4-72a03db847d4
# ╠═41d9598c-3011-4e14-8684-289a172cec10
# ╟─bd1b97c5-04ee-499b-81d7-4bf11e1a4d07
# ╟─c23a2871-6108-4c15-853a-9f2deb41ad53
# ╟─c7c5947b-4caf-4278-af25-c6efdf37557a
# ╟─c1d9b788-0454-4fb4-9eca-f08a8f693af5
# ╟─afbb7662-85e1-4a35-b82f-bce445cf0936
# ╟─4ba352ad-7f94-4f00-ae90-49c92226d0ae
# ╟─9c6874cf-6dee-489f-b9ed-89e86ecdb865
# ╟─cca6bd64-0735-4bd4-8149-7f03f7f26e57
# ╟─cffd033c-9ba9-4147-922e-2265b9e46485
# ╟─e1bcc8dd-009f-4f82-832f-0d8db11b700d
# ╟─2557c704-295a-4770-bbeb-41a94257738b
# ╟─4000f0d1-f014-4ed2-bb6e-de637e47a76d
# ╟─35c1d390-6b67-4ae4-815b-fd5eebdb1ee2
# ╟─04c46c48-a297-4955-90bd-a51b6ad9b310
# ╟─a69868ac-f4e5-4125-9584-7a0750180161
# ╟─c16f9c18-e776-45c8-bcff-66c78627928d
# ╟─1895d767-4018-43a8-94cd-174f321daca1
# ╠═05ce80f3-67e6-4e61-9447-4d703e1c67eb
# ╟─edb2c820-0b38-4f4c-8779-b0f45815b086
# ╟─ad797a54-db6f-4d85-aed2-f8f8ec774c0e
# ╠═12692d0c-2a1f-4ef2-b529-451faa7c9b00
# ╟─057e1b24-e9fa-4aa5-b9b1-97181b096851
# ╟─2c93ad8b-c489-4d37-a39f-a116715f1cfc
# ╟─5c83f904-5ff8-4056-b6a7-dc4ea8b3c993
# ╟─c644bcd3-afef-4446-ae11-2cce4b37eb88
# ╟─cb273532-f78e-48f6-9a32-5bbfc05164dc
# ╟─7f592271-13b2-4d4e-abe7-495172544e14
# ╟─8419b89c-80c1-427e-bf68-03c3a07e8ef2
# ╟─fe2181e1-ef9f-4b6a-aff2-a06f41f166df
# ╟─35edcb27-2cde-4fc8-a2ba-7f455493c627
# ╟─2b922c32-d0da-4813-b1ad-abb5167f4ce4
# ╟─1fa4dabd-3459-4187-b9f2-7e1eee56d28a
# ╟─8391202d-cec8-4b0c-bfc2-1a01419851d4
# ╟─a1cffba2-aab6-4ce5-b5c1-fe7f55f397f9
# ╟─f669ec62-dca0-42c9-a7b7-8024f6e9c7a9
# ╠═390010ce-72dd-4b69-a486-7bcc1744859f
# ╟─43a443c2-3f6d-426f-ab72-bbd67873b92e
# ╠═49f95b2d-6186-470b-956c-1e6bb3ae3de2
# ╟─abf832f5-7cb4-40e7-a27e-2bdec69c910a
# ╠═cd6c0607-ad69-455d-bc3b-6ce05fc87746
# ╟─78e2f78e-061e-4a92-8cce-4c82a46c6e31
# ╠═1a780e63-d0aa-4ad5-a76f-0314c50e3c29
# ╟─be81679d-e8b1-4dc4-b7d1-489fe363f37f
# ╠═49a6d562-d47c-470b-ae54-601fffd12c68
# ╟─be1e91a5-011d-425a-be16-ab7b45b6823f
# ╠═9362414b-e883-4569-9f31-f4ce08d9a0e5
# ╟─9c4a07a8-4144-4e01-ae25-d35c60db5951
# ╟─f84e13af-a1c3-40a5-80a6-b838410b24c7
# ╠═11a363b2-90c7-43ac-a563-257056c66908
# ╟─f1fd0927-4d06-41df-8de4-6def18e26a22
# ╟─da1d8381-5b15-475e-a693-4696689fa6d3
# ╟─fdb13094-ef0e-4626-9e57-4110c0d2ccae
# ╠═bcc72069-c9c9-4eb9-96a1-8528cd60c100
# ╠═fa1e19f1-9cbd-4454-9bf1-a1fc8cdcf52a
# ╠═5efc650a-92a5-4350-9eda-3e7b61f491f5
# ╠═ad3bb2f0-b8b7-489d-8603-53ebd01ab86f
# ╠═2bb008a1-82e2-487f-b2f5-0d27eea804de
# ╠═789cab47-ef60-4c0c-b380-42d9fadee744
# ╠═b2bc41af-aba3-484f-97ed-5558987f4d93
# ╠═531d6c8a-c325-4e9c-9496-6c69b0abed6b
# ╠═c8bdc59a-b830-41d7-903e-338a17220d18
# ╠═3a6ae0de-3774-43d1-aad0-0c1e3edd99e8
# ╟─0a09e61c-7c2b-4088-9fb8-465189ba1768
# ╠═c9b02af3-34ca-4f74-8611-0112b83942bb
# ╠═2588a536-5bfd-4af8-8b40-1a918792cd6a
# ╟─b0a9c155-65f7-44f3-a9bf-77447da741ab
# ╟─34feb3a2-01a2-48a3-87c7-47000b18c39c
# ╟─93ba50b7-098e-4b3d-a3d4-ad27a5d67e0f
# ╟─5766096f-96dc-44f9-ae72-4f75f441594f
# ╠═4e40b2ae-3e70-47bc-808f-1acd2615615a
# ╟─6d7063b7-278f-4d5c-be3e-c4c0edceaf44
# ╟─0e810c29-3155-4d30-9b81-55e6cdc1be5a
# ╟─bdd4566f-3800-4c9c-b91e-ac3c5a65580a
# ╠═4a4cf9f2-21b5-4685-9ce8-99f76556811c
# ╟─09689df6-67a3-4f6e-aeb3-7bacc4d738e3
# ╟─f51d1b16-ec2c-41d7-97af-56688bef276d
# ╠═9a1f8687-df62-4af4-a33e-c7b864c6f556
# ╠═fd8e8644-aedb-4e1c-a55f-12abba02b1c9
# ╟─696f0722-80be-453a-8dee-1ceac68f0f0e
# ╟─79b30313-e600-4356-b589-69fbb9bdc04d
# ╟─7d10fdd7-197f-45f8-b316-c4774b0a1f79
# ╟─c306ae6c-8acc-440d-94f2-4d17c01fa999
# ╟─9c386789-44b7-4d38-95ca-beeaecb311b0
# ╟─13054251-e17d-4469-8a65-281ffd3b5999
# ╟─df7041ea-07b6-4e13-b463-b6fa7b95111c
# ╟─cac4054f-21df-4aac-be8e-ac11e30a1181
# ╟─47831542-8188-496d-b712-b8fc4db18694
# ╟─d65ae8f6-07be-48f7-a1c8-fc493c5cde43
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
